@@ -21,16 +21,8 @@ use Perl6::Pod::To::Mem;
 use Perl6::Pod::To::XML;
 use Perl6::Pod::To::DocBook;
 use Perl6::Pod::To::XHTML;
-use XML::ExtOn::Writer;
 use XML::Flow;
-use XML::ExtOn qw( create_pipe split_pipe);
-
-sub new {
-    my $class = shift;
-    $class = ref $class if ref $class;
-    my $self = bless( {@_}, $class );
-    return $self;
-}
+use XML::ExtOn ('create_pipe');
 
 =head2 parse_mem \$pod_str, ['filter1']
 
@@ -49,7 +41,7 @@ sub parse_mem {
 
 }
 
-=head2 parse_to_xml \$pod_str, ['filter1']
+=head2 parse_mem \$pod_str, ['filter1']
 
 return out_put from To::Mem formatter
 
@@ -60,33 +52,15 @@ sub parse_to_xml {
     my ( $text, @filters ) = @_;
     my $out = '';
     my $to_mem = new Perl6::Pod::To::XML:: out_put => \$out;
-#    $to_mem->parse(\$text);
-#    return wantarray ? ( $to_mem, $f, $out ) : $out;
     my ( $p, $f ) = $test->make_parser( @filters, $to_mem );
     $p->parse( \$text );
     return wantarray ? ( $p, $f, $out ) : $out;
 }
 
-=head2 pod2xml \$pod_str, ['filter1']
-
-return out_put from To::Mem formatter
-
-=cut
-
-sub pod6xml {
-    my $test = shift;
-    my ( $text, @filters ) = @_;
-    my $out = '';
-    my $to_mem = new Perl6::Pod::To::XML:: out_put => \$out, header=>1;
-    my $p = create_pipe(@filters,$to_mem);
-    $p->parse(\$text);
-    return wantarray ? ( $to_mem, $out ) : $out;
-}
-
 sub make_xhtml_parser {
     my $t          = shift;
     my $out        = shift;
-    my $xml_writer = new XML::ExtOn::Writer:: Output => $out;
+    my $xml_writer = new XML::SAX::Writer:: Output => $out;
     my $out_filters =
       create_pipe( create_pipe( @_ ? @_ : 'XML::ExtOn', $xml_writer ) );
     my ( $p, $f ) = Perl6::Pod::To::to_abstract(
@@ -133,7 +107,6 @@ sub make_parser {
     }
     my $out_formatter = $_[-1];
     my $p = create_pipe( 'Perl6::Pod::Parser', @_ );
-    $out_formatter =  split_pipe($p)->[-1]; 
     return wantarray ? ( $p, $out_formatter ) : $p;
 
 }
